import { LogoutOutlined } from '@ant-design/icons';
import { AppBar, Toolbar, Typography, styled } from '@mui/material';
import { Avatar, Button, Dropdown, MenuProps, Row } from 'antd';
import { shallowEqual } from 'react-redux';
import { Link } from 'react-router-dom';
import { logout } from '../../features/usersSlice';
import { useAppDispatch, useAppSelector } from '../../store/hooks';

const StyledLink = styled(Link)(() => ({
  color: 'inherit',
  textDecoration: 'none',
  ['&:hover']: { color: 'inherit' },
}));

export const AppToolBar = () => {
  const dispatch = useAppDispatch();
  const { user } = useAppSelector((state) => state.user, shallowEqual);

  const items: MenuProps['items'] = [
    {
      label: (
        <Button danger icon={<LogoutOutlined />} onClick={() => dispatch(logout())}>
          Logout
        </Button>
      ),
      key: '0',
    },
  ];

  return (
    <>
      <AppBar position="fixed">
        <Toolbar style={{ width: '100%' }}>
          <Row justify={'space-between'} align={'middle'} style={{ width: '100%' }}>
            {user ? (
              <Typography variant="h6" component={StyledLink} to={'/'}>
                Computer parts shop
              </Typography>
            ) : (
              <Typography variant="h6">Auth</Typography>
            )}

            {user && (
              <Row align={'middle'}>
                <Typography variant="h6" style={{ marginRight: '15px' }}>
                  Welcome {user?.username}
                </Typography>

                <Dropdown menu={{ items }} trigger={['click']}>
                  <Avatar size={40}>
                    <Typography style={{ textTransform: 'capitalize', fontSize: '20px' }}>
                      {user?.username[0]}
                    </Typography>
                  </Avatar>
                </Dropdown>
              </Row>
            )}
          </Row>
        </Toolbar>
      </AppBar>
    </>
  );
};
